//
//  ContentView.swift
//  TeachMate
//
//  Created by Hongli on 2025/3/12.
//

import SwiftUI
import SwiftData

struct ContentView: View {
    @Environment(\.modelContext) private var modelContext
    @Query private var semesters: [Semester]
  
    // Add a state to track the selected navigation item
    @State private var selectedNavItem: NavItem? = .schedule
    @State private var selectedSemester: Semester?
    @State private var isShowingSemesterForm = false
    
    // Define navigation items
    enum NavItem: String, Identifiable, CaseIterable {
        case schedule = "课程表"
        case calendar = "教学历"
        case reminders = "提醒事项"
        case courseManager = "课程管理"
        
        var id: String { self.rawValue }
        
        var icon: String {
            switch self {
            case .schedule: return "calendar.day.timeline.left"
            case .calendar: return "calendar"
            case .reminders: return "bell"
            case .courseManager: return "list.bullet.below.rectangle"
            }
        }
    }

    var body: some View {
        NavigationSplitView {
            List(selection: $selectedNavItem) {
                // Top section with main navigation items
                Section {
                    ForEach(NavItem.allCases) { item in
                        NavigationLink(value: item) {
                            Label(item.rawValue, systemImage: item.icon)
                        }
                    }
                }
                
                // Bottom section with semester list
                Section("学期") {
                    ForEach(semesters) { semester in
                        NavigationLink(value: semester) {
                            HStack {
                                if semester.isCurrent {
                                    Image(systemName: "star.fill")
                                        .foregroundColor(.yellow)
                                        .font(.caption)
                                } else {
                                    Image(systemName: "star")
                                        .foregroundColor(.secondary)
                                        .font(.caption)
                                }
                                
                                VStack(alignment: .leading) {
                                    Text(semester.title)
                                        .font(.headline)
                                    Text("第1周 - 第\(semester.weeksCount)周")
                                        .font(.caption)
                                        .foregroundColor(.secondary)
                                }
                            }
                        }
                        .contextMenu {
                            Button {
                                setAsCurrentSemester(semester)
                            } label: {
                                Label("设置为当前学期", systemImage: "star")
                            }
                            
                            Divider()
                            
                            Button(role: .destructive) {
                                if let index = semesters.firstIndex(where: { $0.id == semester.id }) {
                                    deleteSemesters(offsets: IndexSet(integer: index))
                                }
                            } label: {
                                Label("删除", systemImage: "trash")
                            }
                        }
                    }
                    .onDelete(perform: deleteSemesters)
                }
            }
#if os(macOS)
            .navigationSplitViewColumnWidth(min: 180, ideal: 200)
#endif
            .toolbar {
#if os(iOS)
                ToolbarItem(placement: .navigationBarTrailing) {
                    EditButton()
                }
#endif
                ToolbarItem {
                    Button(action: { isShowingSemesterForm = true }) {
                        Label("Add Semester", systemImage: "plus")
                    }
                }
            }
            .sheet(isPresented: $isShowingSemesterForm) {
                SemesterFormView()
            }
        } detail: {
            if let selectedNavItem = selectedNavItem {
                // Show content based on selected navigation item
                switch selectedNavItem {
                case .schedule:
                    if let currentSemester = semesters.first(where: { $0.isCurrent }) {
                        CourseScheduleView(semester: currentSemester)
                            .frame(maxWidth: .infinity, maxHeight: .infinity)
                            #if os(macOS)
                            .adjustWindowSize(to: .schedule)
                            #endif
                    } else if !semesters.isEmpty {
                        CourseScheduleView(semester: semesters[0])
                            .frame(maxWidth: .infinity, maxHeight: .infinity)
                            #if os(macOS)
                            .adjustWindowSize(to: .schedule)
                            #endif
                    } else {
                        VStack {
                            Text("请先添加学期")
                                .font(.title2)
                            Text("在添加学期后，将自动显示课程表")
                                .foregroundColor(.secondary)
                        }
                    }
                case .calendar:
                    if let currentSemester = semesters.first(where: { $0.isCurrent }) {
                        AcademicCalendarView(semester: currentSemester)
                            .frame(maxWidth: .infinity, maxHeight: .infinity)
                            #if os(macOS)
                            .adjustWindowSize(to: .calendar)
                            #endif
                    } else if !semesters.isEmpty {
                        AcademicCalendarView(semester: semesters[0])
                            .frame(maxWidth: .infinity, maxHeight: .infinity)
                            #if os(macOS)
                            .adjustWindowSize(to: .calendar)
                            #endif
                    } else {
                        VStack {
                            Text("请先添加学期")
                                .font(.title2)
                            Text("在添加学期后，将自动显示教学日历")
                                .foregroundColor(.secondary)
                        }
                    }
                case .reminders:
                    Text("提醒事项内容")
                case .courseManager:
                    CourseManagerView()
                }
            } else if let semester = selectedSemester {
                // Show semester detail
                VStack(alignment: .leading, spacing: 16) {
                    Text(semester.title)
                        .font(.largeTitle)
                        .bold()
                    
                    Group {
                        HStack {
                            Text("开始日期:")
                            Text(semester.startDate, format: .dateTime.day().month().year())
                        }
                        
                        HStack {
                            Text("结束日期:")
                            Text(semester.endDate, format: .dateTime.day().month().year())
                        }
                        
                        HStack {
                            Text("总周数:")
                            Text("\(semester.weeksCount)周")
                        }
                        
                        if let currentWeek = semester.currentWeekNumber() {
                            HStack {
                                Text("当前周数:")
                                Text("第\(currentWeek)周")
                                    .foregroundColor(.blue)
                                    .bold()
                            }
                        }
                    }
                    .font(.body)
                    
                    Spacer()
                }
                .padding()
                .frame(maxWidth: .infinity, alignment: .leading)
            } else {
                Text("请选择一个项目")
            }
        }
    }

    private func deleteSemesters(offsets: IndexSet) {
        withAnimation {
            for index in offsets {
                modelContext.delete(semesters[index])
            }
        }
    }
    
    private func setAsCurrentSemester(_ semester: Semester) {
        // First, set all semesters to not current
        for existingSemester in semesters {
            existingSemester.isCurrent = false
        }
        
        // Then set the selected semester as current
        semester.isCurrent = true
    }
}

#Preview {
    ContentView()
        .modelContainer(PreviewData.createSemesterContainer())
}
